@@ -4,6 +4,10 @@
 # @Author       : Mark Shawn
 # @Email        : shawninjuly@gmai.com
 # ------------------------------------
+import os
+PROJECT_DIR = os.path.abspath(os.path.dirname(__file__))
+DATA_DIR    = os.path.join(PROJECT_DIR, "data")
+LOG_DIR     = os.path.join(PROJECT_DIR, "log")
 
 QINIU_DOMAIN = 'http://img.nanchuan.site'
 QINIU_BUCKET = "pfa"
